# AWS Cloud Resource Utils - Library (ACRU-L)

Pronounced _Ah-crew-el (*ə-kroo͞′l*)_

An open source framework for collecting and reusing AWS CDK constructs and stacks.

## Installation

`poetry add -D acru-l`

`pip install acru-l`

## Usage


## Core Concepts

* Resources - Extended constructs
* Services - Collections of Resources that build a service interface
* Stacks - Collections of Services

### Resources
Extended constructs with set defaults

### Services

REAL (RDS-Elasticache-APIGateway-Lambda)

LAD (Lambda-APIGateway-DynamoDB)

### Stacks
Postgres Redis REAL Stack

Global LAD Stack